@@ -18,7 +18,10 @@ sub process {
 	### points are PNGRGBAs
 
 	for (my $i = 0; $i < length($imgrepr->{points}); $i++) {
-		push($self->{lines_points}, $self->investigate_neighbourhood_of_points($i, $imgrepr, GFX::Enhancer::PointsInvestigator->new));
+		if (my (@rgbasl) = $self->investigate_neighbourhood_of_points($i, $imgrepr, GFX::Enhancer::PointsInvestigator->new)) {
+			push($self->{lines_points}, @rgbasl);
+			$i += length(@rgbasl); ### extraneous points added to
+		}
 	}		
 }
 
@@ -27,7 +30,7 @@ sub process {
 sub investigate_neighbourhood_of_points {
 	my ($self, $rgba_point_index, $imgrepr, $investigator) = @_;
 
-	return ($investigator->calculate_neighbourhood($rgba_point_index, $imgrepr));
+	return ($investigator->calculate_neighbourhood($rgba_point_index, $self->{lines_points}, $imgrepr));
 }
 
 1;
